package com.syc.slm.slmbi.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.syc.slm.common.core.util.R;
import com.syc.slm.slmbi.dto.HistoryVariableDTO;
import com.syc.slm.slmbi.dto.RealTimeVariableDTO;
import com.syc.slm.slmbi.dto.VariableDTO;
import com.syc.slm.slmbi.service.VariableService;
import com.syc.slm.slmbi.vo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * slm-bi
 * 用户信息
 *
 * @author : lin
 * @date : 2021-03-25 18:45
 **/
@RestController
@RequestMapping("/{appId}/variables")
@Api(description = "变量控件", tags = "变量控件TAG")
public class VariableController {
    @Autowired
    private VariableService variableService;

    @GetMapping
    @ApiOperation("获取变量列表")
    @ApiImplicitParam(name = "appId", value = "租户id", required = true)
    public R<IPage<VariableVo>> getVariableList(@PathVariable String appId, VariableDTO variableDTO) {
        return R.ok(variableService.getVariableList(variableDTO));
    }

    @GetMapping("/real-time")
    @ApiOperation("获取变量实时数据")
    @ApiImplicitParam(name = "appId", value = "租户id", required = true)
    public R<Map<String, List<Map<String, RealTimeVariableVo>>>> getVariableRealTimeDataList(@PathVariable String appId,
        RealTimeVariableDTO variableDTO) {
        return R.ok(variableService.getVariableRealTimeDataList(variableDTO));
    }

    @GetMapping("/source")
    @ApiOperation("获取变量来源列表")
    @ApiImplicitParam(name = "appId", value = "租户id", required = true)
    public R<List<VariableSourceVo>> getVariableSourceList(@PathVariable String appId) {
        return R.ok(variableService.getVariableSourceList());
    }

    @GetMapping("/device")
    @ApiOperation("获取变量所属设备列表")
    @ApiImplicitParam(name = "appId", value = "租户id", required = true)
    public R<List<VariableDeviceVo>> getVariableDeviceList(@PathVariable String appId) {
        return R.ok(variableService.getVariableDeviceList());
    }

    @GetMapping("/history")
    @ApiOperation("获取变量历史数据")
    @ApiImplicitParam(name = "appId", value = "租户id", required = true)
    public R<Map<String, List<Map<String, HistoryVariableVo>>>> getVariableHistoryDataList(@PathVariable String appId,
        HistoryVariableDTO variableDTO) {
        return R.ok(variableService.getVariableHistoryDataList(variableDTO));
    }
}
